pub struct MessageValidationError { /* private fields */ }Expand description
A message is not valid.
Implementations
Sourceimpl MessageValidationError
impl MessageValidationError
Sourcepub const fn kind(&self) -> &MessageValidationErrorType
pub const fn kind(&self) -> &MessageValidationErrorType
Immutable reference to the type of error that occurred.
Sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
Sourcepub fn into_parts(
self,
) -> (MessageValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts( self, ) -> (MessageValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.
Sourcepub fn from_validation_error(
kind: MessageValidationErrorType,
source: ValidationError,
) -> Self
pub fn from_validation_error( kind: MessageValidationErrorType, source: ValidationError, ) -> Self
Create a MessageValidationError from a ValidationError.